@@ -1,16 +1,17 @@
-# -*- coding: utf-8 -*-
 """Testcases for new cssutils.tokenize.Tokenizer
 
 TODO: old tests as new ones are **not complete**!
 """
 
 import sys
-from . import basetest
+
+import pytest
+
 import cssutils.tokenize2 as tokenize2
 from cssutils.tokenize2 import Tokenizer
 
 
-class TokenizerTestCase(basetest.BaseTestCase):
+class TestTokenizer:
 
     testsall = {
         # IDENT
@@ -73,21 +74,13 @@ class TokenizerTestCase(basetest.BaseTestCase):
         ' "" ': [('S', ' ', 1, 1), ('STRING', '""', 1, 2), ('S', ' ', 1, 4)],
         ' "\'" ': [('S', ' ', 1, 1), ('STRING', '"\'"', 1, 2), ('S', ' ', 1, 5)],
         " '' ": [('S', ' ', 1, 1), ('STRING', "''", 1, 2), ('S', ' ', 1, 4)],
-        # until 0.9.5.x
-        # u"'\\\n'": [('STRING', u"'\\\n'", 1, 1)],
-        # u"'\\\n\\\n\\\n'": [('STRING', u"'\\\n\\\n\\\n'", 1, 1)],
-        # u"'\\\f'": [('STRING', u"'\\\f'", 1, 1)],
-        # u"'\\\r'": [('STRING', u"'\\\r'", 1, 1)],
-        # u"'\\\r\n'": [('STRING', u"'\\\r\n'", 1, 1)],
-        # u"'1\\\n2'": [('STRING', u"'1\\\n2'", 1, 1)],
-        # from 0.9.6a0 escaped nl is removed from string
         "'\\\n'": [('STRING', "''", 1, 1)],
         "'\\\n\\\n\\\n'": [('STRING', "''", 1, 1)],
         "'\\\f'": [('STRING', "''", 1, 1)],
         "'\\\r'": [('STRING', "''", 1, 1)],
         "'1\\\n2'": [('STRING', "'12'", 1, 1)],
         "'1\\\r\n2'": [('STRING', "'12'", 1, 1)],
-        # ur'"\0020|\0020"': [('STRING', u'"\\0020|\\0020"', 1, 1)],
+        # r'"\0020|\0020"': [('STRING', '"\\0020|\\0020"', 1, 1)],
         r'"\61|\0061"': [('STRING', '"a|a"', 1, 1)],
         # HASH
         ' #a ': [('S', ' ', 1, 1), ('HASH', '#a', 1, 2), ('S', ' ', 1, 4)],
@@ -101,8 +94,8 @@ class TokenizerTestCase(basetest.BaseTestCase):
         ' .0 ': [('S', ' ', 1, 1), ('NUMBER', '.0', 1, 2), ('S', ' ', 1, 4)],
         ' -0 ': [
             ('S', ' ', 1, 1),
-            # ('CHAR', u'-', 1, 2),
-            # ('NUMBER', u'0', 1, 3),
+            # ('CHAR', '-', 1, 2),
+            # ('NUMBER', '0', 1, 3),
             ('NUMBER', '-0', 1, 2),
             ('S', ' ', 1, 4),
         ],
@@ -214,8 +207,8 @@ class TokenizerTestCase(basetest.BaseTestCase):
         ],
         # specials
         'c\\olor': [('IDENT', 'c\\olor', 1, 1)],
-        # u'-1': [('CHAR', u'-', 1, 1), ('NUMBER', u'1', 1, 2)],
-        # u'-1px': [('CHAR', u'-', 1, 1), ('DIMENSION', u'1px', 1, 2)],
+        # '-1': [('CHAR', '-', 1, 1), ('NUMBER', '1', 1, 2)],
+        # '-1px': [('CHAR', '-', 1, 1), ('DIMENSION', '1px', 1, 2)],
         '-1': [('NUMBER', '-1', 1, 1)],
         '-1px': [('DIMENSION', '-1px', 1, 1)],
         # ATKEYWORD
@@ -255,11 +248,6 @@ class TokenizerTestCase(basetest.BaseTestCase):
         ' *= ': [('S', ' ', 1, 1), ('SUBSTRINGMATCH', '*=', 1, 2), ('S', ' ', 1, 4)],
         '*==': [('SUBSTRINGMATCH', '*=', 1, 1), ('CHAR', '=', 1, 3)],
         # BOM only at start
-        #        u'\xFEFF ': [('BOM', u'\xfeFF', 1, 1),
-        #                  ('S', u' ', 1, 1)],
-        #        u' \xFEFF ': [('S', u' ', 1, 1),
-        #                  ('IDENT', u'\xfeFF', 1, 2),
-        #                  ('S', u' ', 1, 5)],
         '\xfe\xff ': [('BOM', '\xfe\xff', 1, 1), ('S', ' ', 1, 1)],
         ' \xfe\xff ': [('S', ' ', 1, 1), ('IDENT', '\xfe\xff', 1, 2), ('S', ' ', 1, 4)],
         '\xef\xbb\xbf ': [('BOM', '\xef\xbb\xbf', 1, 1), ('S', ' ', 1, 1)],
@@ -509,31 +497,10 @@ class TokenizerTestCase(basetest.BaseTestCase):
         "url('a'": [('URI', "url('a')", 1, 1)],
     }
 
-    def setUp(self):
+    def setup(self):
         # log = cssutils.errorhandler.ErrorHandler()
         self.tokenizer = Tokenizer()
 
-    #    NOT USED
-    #    def test_push(self):
-    #        "Tokenizer.push()"
-    #        r = []
-    #        def do():
-    #            T = Tokenizer()
-    #            x = False
-    #            for t in T.tokenize('1 x 2 3'):
-    #                if not x and t[1] == 'x':
-    #                    T.push(t)
-    #                    x = True
-    #                r.append(t[1])
-    #            return ''.join(r)
-    #
-    #        # push reinserts token into token stream, so x is doubled
-    #        self.assertEqual('1 xx 2 3', do())
-
-    #    def test_linenumbers(self):
-    #        "Tokenizer line + col"
-    #        pass
-
     def test_tokenize(self):
         "cssutils Tokenizer().tokenize()"
         import cssutils.cssproductions
@@ -552,11 +519,11 @@ class TokenizerTestCase(basetest.BaseTestCase):
             tokens = tokenizer.tokenize(css)
             for i, actual in enumerate(tokens):
                 expected = tests[css][i]
-                self.assertEqual(expected, actual)
+                assert expected == actual
 
             # check if all same number of tokens
             tokens = list(tokenizer.tokenize(css))
-            self.assertEqual(len(tokens), len(tests[css]))
+            assert len(tokens) == len(tests[css])
 
     def test_tokenizefullsheet(self):
         "cssutils Tokenizer().tokenize(fullsheet=True)"
@@ -579,23 +546,20 @@ class TokenizerTestCase(basetest.BaseTestCase):
                     expected = tests[css][i]
                 except IndexError:
                     # EOF is added
-                    self.assertEqual(actual[0], 'EOF')
+                    assert actual[0] == 'EOF'
                 else:
-                    self.assertEqual(expected, actual)
+                    assert expected == actual
 
             # check if all same number of tokens
             tokens = list(tokenizer.tokenize(css, fullsheet=True))
             # EOF is added so -1
-            self.assertEqual(len(tokens) - 1, len(tests[css]))
+            assert len(tokens) - 1 == len(tests[css])
 
 
-class TokenizerUtilsTestCase(basetest.BaseTestCase, metaclass=basetest.GenerateTests):
+class TestTokenizerUtils:
     """Tests for the util functions of tokenize"""
 
-    def gen_test_has_at(self, string, pos, text, expected):
-        self.assertEqual(tokenize2.has_at(string, pos, text), expected)
-
-    gen_test_has_at.cases = [
+    has_at_cases = [
         ('foo', 0, 'foo', True),
         ('foo', 0, 'f', True),
         ('foo', 1, 'o', True),
@@ -605,18 +569,17 @@ class TokenizerUtilsTestCase(basetest.BaseTestCase, metaclass=basetest.GenerateT
         ('foo', 0, 'foobar', False),
     ]
 
-    def gen_test_suffix_eq(self, string, pos, suffix, expected):
-        self.assertEqual(tokenize2.suffix_eq(string, pos, suffix), expected)
+    @pytest.mark.parametrize("string, pos, text, expected", has_at_cases)
+    def test_has_at(self, string, pos, text, expected):
+        assert tokenize2.has_at(string, pos, text) == expected
 
-    gen_test_suffix_eq.cases = [
+    suffix_eq_cases = [
         ('foobar', 0, 'foobar', True),
         ('foobar', 3, 'bar', True),
         ('foobar', 3, 'foo', False),
         ('foobar', 10, 'bar', False),
     ]
 
-
-if __name__ == '__main__':
-    import unittest
-
-    unittest.main()
+    @pytest.mark.parametrize("string, pos, suffix, expected", suffix_eq_cases)
+    def test_suffix_eq(self, string, pos, suffix, expected):
+        assert tokenize2.suffix_eq(string, pos, suffix) == expected
