@@ -3,9 +3,9 @@
 import cssutils
 
 print("\n**SameNamePropertyList is replaced with style.getProperties() from 0.9.4**")
-cssutils.ser.prefs.keepComments = False # remove for now
+cssutils.ser.prefs.keepComments = False  # remove for now
 
-cssText='''    background: white url(paper.png) scroll; /* for all UAs */
+cssText = '''    background: white url(paper.png) scroll; /* for all UAs */
     background: white url(ledger.png) fixed; /* for UAs that do fixed backgrounds */
 '''
 print("\n>>> # cssText")
@@ -18,7 +18,7 @@ print('>>> print style.cssText')
 print(style.cssText)
 
 print("\n>>> cssutils.ser.prefs.keepAllProperties = True # output all values")
-cssutils.ser.prefs.keepAllProperties = True # output all values
+cssutils.ser.prefs.keepAllProperties = True  # output all values
 print('>>> style.cssText # with keepAllProperties==True:')
 print(style.cssText)
 print()
@@ -28,7 +28,8 @@ print(">>> proplist = style.getProperties('background', all=True)")
 proplist = style.getProperties('background', all=True)
 print(">>> proplist\n", proplist)
 print(">>> for prop in proplist: print '\\t', prop.value")
-for prop in proplist: print("\t", prop.value)
+for prop in proplist:
+    print("\t", prop.value)
 print()
 
 print(">>> # overwrite the current property, to overwrite all iterate over proplist")
